@@ -8,3 +8,7 @@ class OpinionSiteLinearWebDriven(OpinionSiteLinear, WebDriven):
     def __init__(self, *args, **kwargs):
         super(OpinionSiteLinearWebDriven, self).__init__(*args, **kwargs)
         WebDriven.__init__(self, args, kwargs)
+
+    def __del__(self):
+        self.close_session()
+        self.close_webdriver_session()
