@@ -15,5 +15,7 @@ from datetime import date
 class Site(md.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
-        self.url = 'http://www.mdcourts.gov/cgi-bin/indexlist.pl?court=cosa&year={current_year}&order=bydate&submit=Submit'.format(current_year=date.today().year)
+        self.url = "https://www.mdcourts.gov/cgi-bin/indexlist.pl?court=cosa&year={current_year}&order=bydate&submit=Submit".format(
+            current_year=date.today().year
+        )
         self.court_id = self.__module__
