@@ -1,9 +1,9 @@
 # Scraper for Oklahoma Attorney General Opinions
-#CourtID: oklaag
-#Court Short Name: OK
-#Author: Andrei Chelaru
-#Reviewer: mlr
-#Date: 2014-07-05
+# CourtID: oklaag
+# Court Short Name: OK
+# Author: Andrei Chelaru
+# Reviewer: mlr
+# Date: 2014-07-05
 
 from datetime import date
 
@@ -22,21 +22,20 @@ class Site(okla.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         d = date.today()
-        self.url = 'http://www.oscn.net/applications/oscn/Index.asp?ftdb=STOKAG&year={year}&level=1'.format(
+        self.url = "http://www.oscn.net/applications/oscn/Index.asp?ftdb=STOKAG&year={year}&level=1".format(
             year=d.year
         )
         self.court_id = self.__module__
 
     def _get_precedential_statuses(self):
-        return ['Unpublished'] * len(self.case_names)
+        return ["Unpublished"] * len(self.case_names)
 
     @staticmethod
     def cleanup_content(content):
         tree = html.fromstring(content)
-        core_element = tree.xpath('//div[contains(concat(" ", normalize-space(@class), " "), " main ")]')[0]
+        core_element = tree.xpath(
+            '//div[contains(concat(" ", normalize-space(@class), " "), " main ")]'
+        )[0]
         return html.tostring(
-            core_element,
-            pretty_print=True,
-            encoding='unicode'
+            core_element, pretty_print=True, encoding="unicode"
         )
-
