@@ -1,9 +1,9 @@
 # Scraper for Oklahoma Court of Criminal Appeals
-#CourtID: oklacrimapp
-#Court Short Name: OK
-#Author: Andrei Chelaru
-#Reviewer: mlr
-#Date: 2014-07-05
+# CourtID: oklacrimapp
+# Court Short Name: OK
+# Author: Andrei Chelaru
+# Reviewer: mlr
+# Date: 2014-07-05
 
 from datetime import date
 
@@ -15,6 +15,6 @@ class Site(okla.Site):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
         d = date.today()
-        self.url = 'http://www.oscn.net/applications/oscn/Index.asp?ftdb=STOKCSCR&year={year}&level=1'.format(
+        self.url = "http://www.oscn.net/applications/oscn/Index.asp?ftdb=STOKCSCR&year={year}&level=1".format(
             year=d.year
         )
