@@ -13,10 +13,10 @@ class Site(OralArgumentSite):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.url = 'http://www.ca4.uscourts.gov/oral-argument/listen-to-oral-arguments'
+        self.url = "http://www.ca4.uscourts.gov/oral-argument/listen-to-oral-arguments"
 
     def _get_download_urls(self):
-        return [href for href in self.html.xpath('//tr/td[2]//a/@href')]
+        return [href for href in self.html.xpath("//tr/td[2]//a/@href")]
 
     def _get_case_names(self):
         return self.text_from_cell(3)
@@ -31,4 +31,7 @@ class Site(OralArgumentSite):
         return self.text_from_cell(2)
 
     def text_from_cell(self, cell_number):
-        return [cell.text_content().strip() for cell in self.html.xpath('//tr/td[%d]' % cell_number)]
+        return [
+            cell.text_content().strip()
+            for cell in self.html.xpath("//tr/td[%d]" % cell_number)
+        ]
