@@ -27,7 +27,7 @@ class Site(OralArgumentSite):
 
     def _get_case_dates(self):
         path = "//tr[@bgcolor]/td[4]/text()"
-        return map(self._return_case_date, self.html.xpath(path))
+        return list(map(self._return_case_date, self.html.xpath(path)))
 
     @staticmethod
     def _return_case_date(s):
