@@ -1,3 +1,5 @@
+import re
+
 from lxml import etree
 
 from .reports import BaseReport
@@ -34,7 +36,7 @@ class PossibleCaseNumberApi(BaseReport):
         ), "session attribute of PossibleCaseNUmberApi cannot be None."
         url = "%s?%s" % (self.url, docket_number.lower())
         logger.info(
-            u"Querying the possible case number endpoint at URL: %s" % url
+            "Querying the possible case number endpoint at URL: %s" % url
         )
         self.response = self.session.get(url)
         self.parse()
@@ -46,6 +48,17 @@ class PossibleCaseNumberApi(BaseReport):
         """
         self.tree = etree.fromstring(text)
 
+    def get_judge_abbrev(self, s):
+        """Get the judge abbreviation from the title string"""
+        regexes = [
+            r"\d\d-[a-zA-Z]{1,4}-\d{1,10}(-(?P<abbrev>.*?))? ",
+        ]
+        for regex in regexes:
+            m = re.search(regex, s)
+            if m:
+                return m.group("abbrev")
+        return ""
+
     def data(
         self, case_name=None, office_number=None, docket_number_letters=None
     ):
@@ -157,7 +170,7 @@ class PossibleCaseNumberApi(BaseReport):
                 ]
                 case_index = get_closest_match_index(case_name, strs)
                 if case_index is None:
-                    logger.warn(
+                    logger.warning(
                         "Got %s candidates, but unable to find good "
                         "match to '%s'" % (len(nodes), case_name)
                     )
@@ -174,11 +187,14 @@ class PossibleCaseNumberApi(BaseReport):
         if nodes:
             node = nodes[0]
             return {
-                u"docket_number": force_unicode(node.xpath("./@number")[0]),
-                u"pacer_case_id": force_unicode(node.xpath("./@id")[0]),
+                "docket_number": force_unicode(node.xpath("./@number")[0]),
+                "pacer_case_id": force_unicode(node.xpath("./@id")[0]),
                 # This could be further post processed to pull out the date closed
                 # and a cleaner title.
-                u"title": force_unicode(node.xpath("./@title")[0]),
+                "title": force_unicode(node.xpath("./@title")[0]),
+                "judge_abbrev": self.get_judge_abbrev(
+                    node.xpath("./@title")[0]
+                ),
             }
         else:
             raise ParsingException("Unable to identify case.")
@@ -228,7 +244,7 @@ class ShowCaseDocApi(BaseReport):
                 attachment_number=attachment_number,
             )
         )
-        logger.info(u"Querying the show_doc_url endpoint with URL: %s" % url)
+        logger.info("Querying the show_doc_url endpoint with URL: %s" % url)
         # Only do a head request, else we get text content we don't need.
         self.response = self.session.head(url, allow_redirects=True)
         self.parse()
